"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.component = component;
exports.componentInfo = componentInfo;
exports.componentPreview = componentPreview;
exports.queryString = queryString;
const node_querystring_1 = __importDefault(require("node:querystring"));
const node_url_1 = __importDefault(require("node:url"));
function componentForType(component, baseUrl, type) {
    if (typeof component === 'string') {
        component = { name: component };
    }
    let href = node_url_1.default.resolve(baseUrl, component.name) + '/';
    if (component.version) {
        href += component.version + '/';
    }
    href += '~' + type;
    return href;
}
function component(component, baseUrl) {
    if (typeof component === 'string') {
        component = { name: component };
    }
    let componentUrl = node_url_1.default.resolve(baseUrl, component.name);
    if (component.version) {
        componentUrl += '/' + component.version;
    }
    componentUrl += queryString(component.parameters);
    return componentUrl;
}
function componentInfo(component, baseUrl) {
    return componentForType(component, baseUrl, 'info');
}
function componentPreview(component, baseUrl) {
    let href = componentForType(component, baseUrl, 'preview');
    if (!!component.parameters && Object.keys(component.parameters).length) {
        href += '/?' + node_querystring_1.default.stringify(component.parameters);
    }
    else {
        href += '/';
    }
    return href;
}
function queryString(parameters = {}) {
    let qs = '';
    if (Object.keys(parameters).length > 0) {
        qs += '?';
        for (const [key, parameter] of Object.entries(parameters)) {
            qs += key + '=' + encodeURIComponent(parameter) + '&';
        }
        if (Object.keys(parameters).length > 0) {
            qs = qs.slice(0, -1);
        }
    }
    return qs;
}
